#
# spec file for package python-nss
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-nss
Version:        1.0.1
Release:        7.6
Summary:        Python bindings for mozilla-nss and mozilla-nspr
License:        GPL-2.0-or-later OR MPL-1.1+ OR LGPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSS/Python_binding_for_NSS
Source:         https://files.pythonhosted.org/packages/source/p/python-nss/python-nss-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM 0001-Rename-DSA-RSA-PublicKey-to-Py-DSA-RSA-PublicKey.patch bmo#1474274 mcepl@suse.com
# Incompatibility with NSS 3.58+
Patch0:         0001-Rename-DSA-RSA-PublicKey-to-Py-DSA-RSA-PublicKey.patch
# PATCH-FIX-OPENSUSE sphinx.patch mcepl@suse.com
# Include sphinx configuration to build docs
Patch1:         sphinx.patch
# PATCH-FIX-OPENSUSE Switch from dist-dir to dist_dir to stop setuptools whine
Patch2:         new-setuptools.patch
# PATCH-FIX-OPENSUSE Stop using six in tests
Patch3:         remove-six.patch
# PATCH-FIX-UPSTREAM fix-ftbfs-python3-12.patch bsc#1219842 mcepl@suse.com
# Patch from https://bugs.debian.org/1055552
Patch4:         fix-ftbfs-python3-12.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  python-rpm-macros
# Required for tests
BuildRequires:  mozilla-nss-tools
%python_subpackages

%description
python-nss is a Python binding for NSS (Network Security Services) and
NSPR (Netscape Portable Runtime). NSS provides cryptography services
supporting SSL, TLS, PKI, PKIX, X509, PKCS*, etc. NSS is an
alternative to OpenSSL and used extensively by major software
projects. NSS is FIPS-140 certified.

%package -n %{name}-doc
Summary:        Documentation files for %name
Group:          Documentation/Other
BuildArch:      noarch

%description -n %{name}-doc
HTML Documentation and examples for %name.

%prep
%autosetup -p1 -n python-nss-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
PYTHONPATH=%{buildroot}%{python_sitearch} python3 -m sphinx doc/sphinx/source build/sphinx/html
rm -rf build/sphinx/html/.buildinfo build/sphinx/html/.doctrees

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python test/run_tests -i
}

%files %{python_files}
%license LICENSE.mpl LICENSE.lgpl LICENSE.gpl
%doc README doc/ChangeLog
%{python_sitearch}/nss
%{python_sitearch}/python_nss-%{version}*-info

%files -n %{name}-doc
%license LICENSE.mpl LICENSE.lgpl LICENSE.gpl
%doc build/sphinx/html

%changelog
* Mon Feb 12 2024 Matej Cepl <mcepl@cepl.eu>
- Add fix-ftbfs-python3-12.patch from
  https://bugs.debian.org/1055552 to fix FTBFS with Python 3.12
  (bsc#1219842).
- Update new-setuptools.patch to make setup.py more compatible
  with the current setuptools.
* Thu Jun 22 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop sphinx .doctrees to make package build reproducible
* Wed Jun 14 2023 Steve Kowalik <steven.kowalik@suse.com>
- Rejig sphinx.patch to not require Sphinx's setuptools machinery.
- Add patch new-setuptools.patch, remove-six.patch.
- Declare -doc subpackage as noarch.
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros
* Tue Dec 15 2020 Matej Cepl <mcepl@suse.com>
- Add missing patches from Fedora package
  (https://src.fedoraproject.org/rpms/python-nss/tree/master):
  - 0001-Rename-DSA-RSA-PublicKey-to-Py-DSA-RSA-PublicKey.patch
    (bmo#1474274)
  - sphinx.patch
- Add generated documentation to -doc subpackage.
* Fri Mar  1 2019 Matej Cepl <mcepl@suse.com>
- Enable tests.
* Wed May  2 2018 tchvatal@suse.com
- Fix SOURCE link to be fetchable
* Thu Feb  1 2018 mrueckert@suse.de
- update to 1.0.1
  see installed /usr/share/doc/packages/python*-nss/ChangeLog
* Thu Feb  1 2018 mrueckert@suse.de
- convert so single spec
* Mon Jun  1 2015 hguo@suse.com
- New package.
